# Generated by Django 4.2.6 on 2025-01-04 16:25

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("tours", "0011_remove_gls_shd_shdentry"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="breaktime",
            options={"verbose_name": "Pause", "verbose_name_plural": "Pauses"},
        ),
        migrations.AlterModelOptions(
            name="chronopostdelivery",
            options={
                "verbose_name": "Chronopost - Livraison",
                "verbose_name_plural": "Chronopost - Livraison",
            },
        ),
        migrations.AlterModelOptions(
            name="chronopostpickup",
            options={
                "verbose_name": "Chronopost - Ramasse",
                "verbose_name_plural": "Chronopost - Ramasse",
            },
        ),
        migrations.AlterModelOptions(
            name="shdentry",
            options={
                "ordering": ["number"],
                "verbose_name": "SHD",
                "verbose_name_plural": "SHD",
            },
        ),
        migrations.AlterModelOptions(
            name="tnt",
            options={
                "verbose_name": "TNT - Fedex",
                "verbose_name_plural": "TNT - Fedex",
            },
        ),
        migrations.AddField(
            model_name="gls",
            name="shd",
            field=models.IntegerField(default=0, verbose_name="SHD"),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="breaktime",
            name="end_time",
            field=models.TimeField(verbose_name="Fin de la pause"),
        ),
        migrations.AlterField(
            model_name="breaktime",
            name="start_time",
            field=models.TimeField(verbose_name="Début de la pause"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="beginning_hour",
            field=models.TimeField(verbose_name="début de la journée"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="charged_packages",
            field=models.IntegerField(verbose_name="Colis chargé"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="charged_points",
            field=models.IntegerField(verbose_name="Points chargés"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Commentaires"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="date",
            field=models.DateField(verbose_name="date"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="ending_hour",
            field=models.TimeField(verbose_name="fin de la journée"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="full_km",
            field=models.IntegerField(verbose_name="Plein / KM"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="including_ip",
            field=models.IntegerField(verbose_name="Dont IP"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="Plaque d'immatriculation"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="livreur",
            ),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="name",
            field=models.CharField(max_length=255, verbose_name="numéro de tournée"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="overdue",
            field=models.IntegerField(verbose_name="HORS DELAIS"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="relay",
            field=models.IntegerField(verbose_name="Relais"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="return_packages",
            field=models.IntegerField(verbose_name="Retour COLIS"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="return_points",
            field=models.IntegerField(verbose_name="Retour POINTS"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="total_points",
            field=models.IntegerField(verbose_name="Total points"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="beginning_hour",
            field=models.TimeField(verbose_name="début de la journée"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Commentaires"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="date",
            field=models.DateField(verbose_name="date"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="ending_hour",
            field=models.TimeField(verbose_name="fin de la journée"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="Plaque d'immatriculation"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="livreur",
            ),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="name",
            field=models.CharField(max_length=255, verbose_name="numéro de tournée"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="picked_points",
            field=models.IntegerField(verbose_name="Point ramassés"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="beginning_hour",
            field=models.TimeField(verbose_name="début de la journée"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Commentaires"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="date",
            field=models.DateField(verbose_name="date"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="days",
            field=models.IntegerField(verbose_name="jours"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="ending_hour",
            field=models.TimeField(verbose_name="fin de la journée"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="Plaque d'immatriculation"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="livreur",
            ),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="morning_pickup",
            field=models.IntegerField(verbose_name="ramassages matin"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="name",
            field=models.CharField(max_length=255, verbose_name="numéro de tournée"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="nights",
            field=models.IntegerField(verbose_name="nuits"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="avp_relay",
            field=models.IntegerField(verbose_name="AVP Relais"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="beginning_hour",
            field=models.TimeField(verbose_name="début de la journée"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Commentaires"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="date",
            field=models.DateField(verbose_name="date"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="ending_hour",
            field=models.TimeField(verbose_name="fin de la journée"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="full_km",
            field=models.IntegerField(verbose_name="Plein / KM"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="Plaque d'immatriculation"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="livreur",
            ),
        ),
        migrations.AlterField(
            model_name="gls",
            name="name",
            field=models.CharField(max_length=255, verbose_name="numéro de tournée"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="packages_charges",
            field=models.IntegerField(verbose_name="Colis chargés"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="packages_delivered",
            field=models.IntegerField(verbose_name="Colis livrés"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="points_charges",
            field=models.IntegerField(verbose_name="Points chargés"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="points_delivered",
            field=models.IntegerField(verbose_name="Points livrés"),
        ),
        migrations.AlterField(
            model_name="shdentry",
            name="gls",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="shd_entries",
                to="tours.gls",
                verbose_name="Tournée GLS",
            ),
        ),
        migrations.AlterField(
            model_name="shdentry",
            name="number",
            field=models.PositiveIntegerField(verbose_name="SHD"),
        ),
        migrations.AlterField(
            model_name="shdentry",
            name="value",
            field=models.IntegerField(verbose_name="valeur"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="beginning_hour",
            field=models.TimeField(verbose_name="début de la journée"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="cad",
            field=models.IntegerField(verbose_name="cad/retour"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="client_numbers",
            field=models.IntegerField(verbose_name="Nombres clients"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Commentaires"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="date",
            field=models.DateField(verbose_name="date"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="ending_hour",
            field=models.TimeField(verbose_name="fin de la journée"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="kilometers",
            field=models.IntegerField(verbose_name="KM/Plein"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="Plaque d'immatriculation"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="livreur",
            ),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="name",
            field=models.CharField(max_length=255, verbose_name="numéro de tournée"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="occasional_abductions",
            field=models.IntegerField(verbose_name="enlèvements occasionnels"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="refused",
            field=models.IntegerField(verbose_name="refuse"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="regular_abductions",
            field=models.IntegerField(verbose_name="enlèvements réguliers"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="totals_clients",
            field=models.IntegerField(verbose_name="totals client"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="totals_clients_abductions",
            field=models.IntegerField(verbose_name="totals clients enlèvements"),
        ),
    ]
