# Generated by Django 4.2.6 on 2025-01-04 15:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("tours", "0006_remove_breaktime_time_breaktime_end_time_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="ciblex",
            name="relais",
            field=models.IntegerField(default="0", verbose_name="relais"),
            preserve_default=False,
        ),
    ]
