# Generated by Django 4.2.6 on 2025-01-04 16:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("tours", "0009_alter_breaktime_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="gls",
            name="packages_refused",
            field=models.IntegerField(blank=True, null=True, verbose_name="Colis refusés"),
        ),
    ]
