{% extends "admin/change_form.html" %}
{% load i18n admin_urls %}

{% block object-tools-items %}
    {{ block.super }}
    {% if original %}
    <li>
        <form method="post">
            {% csrf_token %}
            <input type="hidden" name="_export_csv" value="1">
            <button type="submit" class="historylink" style="border: none; background: none; cursor: pointer; color: var(--object-tools-fg); padding: 10px 15px; font-size: 0.8125rem; font-weight: bold;">
                {% translate "Exporter en CSV" %}
            </button>
        </form>
    </li>
    {% endif %}
{% endblock %}
