# Generated by Django 4.2.6 on 2025-01-04 16:30

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("tours", "0013_alter_shdentry_number"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="gls",
            name="shd",
        ),
    ]
