# Generated by Django 4.2.6 on 2025-01-04 16:10

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("tours", "0008_alter_breaktime_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="breaktime",
            options={
                "verbose_name": "Break Time",
                "verbose_name_plural": "Break Times",
            },
        ),
        migrations.AlterModelOptions(
            name="chronopostdelivery",
            options={
                "verbose_name": "Chronopost Delivery",
                "verbose_name_plural": "Chronopost Delivery",
            },
        ),
        migrations.AlterModelOptions(
            name="chronopostpickup",
            options={
                "verbose_name": "Chronopost Pickup",
                "verbose_name_plural": "Chronopost Pickup",
            },
        ),
        migrations.AddField(
            model_name="gls",
            name="packages_refused",
            field=models.IntegerField(default=0, verbose_name="Colis Refusés"),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="breaktime",
            name="end_time",
            field=models.TimeField(verbose_name="End of Break"),
        ),
        migrations.AlterField(
            model_name="breaktime",
            name="start_time",
            field=models.TimeField(verbose_name="Start of Break"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="beginning_hour",
            field=models.TimeField(verbose_name="Beginning Hour"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="charged_packages",
            field=models.IntegerField(verbose_name="Charged Packages"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="charged_points",
            field=models.IntegerField(verbose_name="Charged Points"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="date",
            field=models.DateField(verbose_name="Tour Date"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="ending_hour",
            field=models.TimeField(verbose_name="Ending Hour"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="full_km",
            field=models.IntegerField(verbose_name="Full KM"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="including_ip",
            field=models.IntegerField(verbose_name="Including IP"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="License Plate"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="Deliveryman",
            ),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="name",
            field=models.CharField(max_length=255, verbose_name="Tour Name"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="overdue",
            field=models.IntegerField(verbose_name="Overdue"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="relay",
            field=models.IntegerField(verbose_name="Relay"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="return_packages",
            field=models.IntegerField(verbose_name="Return Packages"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="return_points",
            field=models.IntegerField(verbose_name="Return Points"),
        ),
        migrations.AlterField(
            model_name="chronopostdelivery",
            name="total_points",
            field=models.IntegerField(verbose_name="Total Points"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="beginning_hour",
            field=models.TimeField(verbose_name="Beginning Hour"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="date",
            field=models.DateField(verbose_name="Tour Date"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="ending_hour",
            field=models.TimeField(verbose_name="Ending Hour"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="License Plate"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="Deliveryman",
            ),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="name",
            field=models.CharField(max_length=255, verbose_name="Tour Name"),
        ),
        migrations.AlterField(
            model_name="chronopostpickup",
            name="picked_points",
            field=models.IntegerField(verbose_name="Picked Points"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="beginning_hour",
            field=models.TimeField(verbose_name="Beginning Hour"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="date",
            field=models.DateField(verbose_name="Tour Date"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="days",
            field=models.IntegerField(verbose_name="days"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="ending_hour",
            field=models.TimeField(verbose_name="Ending Hour"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="License Plate"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="Deliveryman",
            ),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="morning_pickup",
            field=models.IntegerField(verbose_name="morning pickups"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="name",
            field=models.CharField(max_length=255, verbose_name="Tour Name"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="nights",
            field=models.IntegerField(verbose_name="nights"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="spare_part",
            field=models.IntegerField(verbose_name="spare part"),
        ),
        migrations.AlterField(
            model_name="ciblex",
            name="synchro",
            field=models.IntegerField(verbose_name="synchro"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="avp_relay",
            field=models.IntegerField(verbose_name="AVP Relay"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="beginning_hour",
            field=models.TimeField(verbose_name="Beginning Hour"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="date",
            field=models.DateField(verbose_name="Tour Date"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="ending_hour",
            field=models.TimeField(verbose_name="Ending Hour"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="full_km",
            field=models.IntegerField(verbose_name="Full KM"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="License Plate"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="Deliveryman",
            ),
        ),
        migrations.AlterField(
            model_name="gls",
            name="name",
            field=models.CharField(max_length=255, verbose_name="Tour Name"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="packages_charges",
            field=models.IntegerField(verbose_name="Packages Charges"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="packages_delivered",
            field=models.IntegerField(verbose_name="Packages Delivered"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="points_charges",
            field=models.IntegerField(verbose_name="Points Charges"),
        ),
        migrations.AlterField(
            model_name="gls",
            name="points_delivered",
            field=models.IntegerField(verbose_name="Points Delivered"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="beginning_hour",
            field=models.TimeField(verbose_name="Beginning Hour"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="cad",
            field=models.IntegerField(verbose_name="cad/return"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="client_numbers",
            field=models.IntegerField(verbose_name="Client numbers"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="comments",
            field=models.TextField(blank=True, null=True, verbose_name="Comments"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="date",
            field=models.DateField(verbose_name="Tour Date"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="ending_hour",
            field=models.TimeField(verbose_name="Ending Hour"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="kilometers",
            field=models.IntegerField(verbose_name="KM/Full"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="license_plate",
            field=models.CharField(max_length=7, verbose_name="License Plate"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="linked_user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="Deliveryman",
            ),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="name",
            field=models.CharField(max_length=255, verbose_name="Tour Name"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="occasional_abductions",
            field=models.IntegerField(verbose_name="occasional abductions"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="refused",
            field=models.IntegerField(verbose_name="Refused"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="regular_abductions",
            field=models.IntegerField(verbose_name="regular abductions"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="totals_clients",
            field=models.IntegerField(verbose_name="totals clients"),
        ),
        migrations.AlterField(
            model_name="tnt",
            name="totals_clients_abductions",
            field=models.IntegerField(verbose_name="total clients abductions"),
        ),
    ]
